==> gorm.app_1.2.4.orig.tar.gz: gorm-1.2.4/Palettes/1Windows/GormDrawerAttributesInspector.m <==
/* 
   GormDrawerAttributesInspector.m
   
   Copyright (C) 2006 Free Software Foundation, Inc.

   Author:  Gregory John Casamento <greg_casamento@yahoo.com>
   Date: 2006
   
   This file is part of GNUstep.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
*/

/* All Rights reserved */

#include <AppKit/AppKit.h>
#include "GormDrawerAttributesInspector.h"

@implementation GormDrawerAttributesInspector
- (id) init
{
  if ([super init] == nil)
    return nil;

  if ([NSBundle loadNibNamed: @"GormDrawerAttributesInspector" owner: self] == NO)
    {
      NSLog(@"Could not gorm GormDrawerAttributesInspector");
      return nil;
    }

  return self;
}

- (void) ok: (id) sender
{
  id drawer = [self object];
  [drawer setPreferredEdge: [[sender selectedItem] tag]];
}

- (void) revert: (id) sender
{
  id drawer = [self object];
  int i = [preferredEdge indexOfItemWithTag: [drawer preferredEdge]];
  if(i != NSNotFound)
    {
      [preferredEdge selectItemAtIndex: i];
    }
}
@end

==> gorm.app_1.2.20.orig.tar.gz: gorm-1.2.20/Palettes/1Windows/GormDrawerAttributesInspector.m <==
/* 
   GormDrawerAttributesInspector.m
   
   Copyright (C) 2006 Free Software Foundation, Inc.

   Author:  Gregory John Casamento <greg_casamento@yahoo.com>
   Date: 2006
   
   This file is part of GNUstep.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
*/

/* All Rights reserved */

#include <AppKit/AppKit.h>
#include "GormDrawerAttributesInspector.h"

@implementation GormDrawerAttributesInspector
- (id) init
{
  if ([super init] == nil)
    return nil;

  if ([NSBundle loadNibNamed: @"GormDrawerAttributesInspector" owner: self] == NO)
    {
      NSLog(@"Could not gorm GormDrawerAttributesInspector");
      return nil;
    }

  return self;
}

- (void) ok: (id) sender
{
  id drawer = [self object];
  [drawer setPreferredEdge: [[sender selectedItem] tag]];
}

- (void) revert: (id) sender
{
  id drawer = [self object];
  NSUInteger i = [preferredEdge indexOfItemWithTag: [drawer preferredEdge]];
  if(i != NSNotFound)
    {
      [preferredEdge selectItemAtIndex: i];
    }
}
@end
